pub fn sys_gettid(
_abi: &mut LinuxRiscv64Abi,
trapframe: &mut Trapframe,
) -> usizeExpand description
Linux gettid system call implementation Returns the calling thread ID (TID). For now, this equals Scarlet Task ID.
pub fn sys_gettid(
_abi: &mut LinuxRiscv64Abi,
trapframe: &mut Trapframe,
) -> usizeLinux gettid system call implementation Returns the calling thread ID (TID). For now, this equals Scarlet Task ID.