pub fn sys_memfd_create(
abi: &mut LinuxRiscv64Abi,
trapframe: &mut Trapframe,
) -> usizeExpand description
Linux sys_memfd_create - Create an anonymous file descriptor for memory mapping
Creates a new anonymous file descriptor that can be used for memory mapping. This is primarily used by Wayland clients for shared memory.
Arguments:
- abi: LinuxRiscv64Abi context
- trapframe: Trapframe containing syscall arguments
- arg0: uname (name for the memfd - can be NULL)
- arg1: flags (MFD_CLOEXEC, MFD_ALLOW_SEALING, etc.)
Returns:
- New file descriptor on success
- usize::MAX (Linux -1) on error